@@ -6,7 +6,8 @@ class NAnimatedCheckBox:
     def __init__(
             self,
             parent: any,
-            font: pygame.font.Font,
+            font: NFont,
+            font_size: int,
             xy: tuple,
             text: str,
             color: tuple = (0, 0, 0),
@@ -17,7 +18,8 @@ class NAnimatedCheckBox:
             stretch: bool = False
     ) -> None:
         super(NAnimatedCheckBox, self).__init__()
-        self.font = font
+        self.font_size = font_size
+        self.font: NChildFont = font.create_size(self.font_size)
         self.x, self.y = xy
         self.w, self.h = 0, 0
         self._width, self._height = self.w, self.h
@@ -52,6 +54,9 @@ class NAnimatedCheckBox:
         self.box_size = 13
         self.margin = 5
         self.checked = False
+        self.auto_scale = True
+        self.min_scale = 1.0
+        self.scale_x, self.scale_y = 1.0, 1.0
         self.multi_lines_align = LABEL_ALIGN_LEFT
         self.surface: pygame.Surface = None  # type: ignore
         self.cursor = cursors.get('DEFAULT')
@@ -67,20 +72,29 @@ class NAnimatedCheckBox:
         setattr(self, name, value)
         if name in ('text', 'color', 'anti_alias', 'mutli_line_align', 'stretch', 'auto_size'):
             self.redraw()
+        elif name in ('font', 'font_size'):
+            self.font = self.font.create_size(self.font_size)
+            self.redraw()
+        elif name in ('scale_x', 'scale_y'):
+            self.min_scale = min(self.scale_x, self.scale_y)
+            self.font.scale(self.min_scale)
+            self.redraw()
         return self
 
     def redraw(self) -> None:
         if self.text.count('\n') <= 0:
-            self.surface = self.font.render(
+            self.surface = self.font.font.render(
                 self.text,
                 self.anti_alias,
                 self.color
             )
             self._width, self._height = self.surface.get_size()
             if self.auto_size:
-                self.w, self.h = self._width, self._height
+                self.w, self.h = r(self._width / self.min_scale), r(self._height / self.min_scale)
             elif self.stretch:
-                self.surface = pygame.transform.scale(self.surface, (self.w, self.h))
+                self.surface = pygame.transform.scale(
+                    self.surface, round_tuple((self.w * self.scale_x, self.h * self.scale_y))
+                )
             if self.auto_size_box:
                 self.box_size = self.h
             return
@@ -89,7 +103,7 @@ class NAnimatedCheckBox:
         surfaces = []
         heights = []
         for _text in self.text.split('\n'):
-            _surface = self.font.render(
+            _surface = self.font.font.render(
                 _text,
                 self.anti_alias,
                 self.color
@@ -113,9 +127,11 @@ class NAnimatedCheckBox:
             )
             total_height += heights[_num]
         if self.auto_size:
-            self.w, self.h = self._width, self._height
+            self.w, self.h = r(self._width / self.min_scale), r(self._height / self.min_scale)
         elif self.stretch:
-            self.surface = pygame.transform.scale(self.surface, (self.w, self.h))
+            self.surface = pygame.transform.scale(
+                self.surface, round_tuple((self.w * self.scale_x, self.h * self.scale_y))
+            )
         if self.auto_size_box:
             self.box_size = self.h
 
@@ -130,34 +146,37 @@ class NAnimatedCheckBox:
         pygame.draw.rect(
             surface,
             self.current_color1.color,
-            (self.x + scroll_x, self.y + scroll_y, self.box_size, self.box_size),
+            round_tuple((self.x * self.scale_x + scroll_x, self.y * self.scale_y + scroll_y,
+                         self.box_size * self.scale_x, self.box_size * self.scale_y)),
             0,
-            self.border_radius
+            r(self.border_radius * self.min_scale)
         )
         if self.checked:
             pygame.draw.rect(
                 surface,
                 self.current_color3.color,
-                (
-                    self.x + scroll_x + self.padding,
-                    self.y + scroll_y + self.padding,
-                    self.box_size - self.padding * 2,
-                    self.box_size - self.padding * 2
-                ),
+                round_tuple((
+                    (self.x + self.padding) * self.scale_x + scroll_x,
+                    (self.y + self.padding) * self.scale_y + scroll_y,
+                    (self.box_size - self.padding * 2) * self.scale_x,
+                    (self.box_size - self.padding * 2) * self.scale_y
+                )),
                 0,
-                self.border_radius
+                r(self.border_radius * self.min_scale)
             )
         pygame.draw.rect(
             surface,
             self.current_color2.color,
-            (self.x + scroll_x, self.y + scroll_y, self.box_size, self.box_size),
-            1,
-            self.border_radius
+            round_tuple((self.x * self.scale_x + scroll_x, self.y * self.scale_y + scroll_y,
+                         self.box_size * self.scale_x, self.box_size * self.scale_y)),
+            r(self.min_scale) or 1,
+            r(self.border_radius * self.min_scale)
         )
         surface.blit(
             self.surface,
-            (self.box_size + self.margin + self.x + self.x_offset + scroll_x, self.y + self.y_offset + scroll_y),
-            None if self.auto_size else (0, 0, self.w - 1, self.h)
+            round_tuple(((self.box_size + self.margin + self.x + self.x_offset) * self.scale_x + scroll_x,
+                         (self.y + self.y_offset) * self.scale_y + scroll_y)),
+            None if self.auto_size else (0, 0, r((self.w - 1) * self.scale_x), r(self.h * self.scale_y))
         )
 
     def _on_mouse_wheel(self, event: pygame.event.Event, bind: bool) -> None:
