@@ -40,6 +40,8 @@ class NWinButton:
         self.color = color
         self.color1 = (225, 225, 225)
         self.color2 = (173, 173, 173)
+        self.disabled_color1 = (191, 191, 191)
+        self.disabled_color2 = (204, 204, 204)
         self.hover_color1 = (229, 241, 251)
         self.hover_color2 = (0, 120, 215)
         self.focus_color1 = (204, 228, 247)
@@ -80,6 +82,13 @@ class NWinButton:
             self.min_scale = min(self.scale_x, self.scale_y)
             self.font.scale(self.min_scale)
             self.redraw()
+        elif name == 'is_enabled':
+            if value:
+                self.current_color1 = self.color1
+                self.current_color2 = self.color2
+            else:
+                self.current_color1 = self.disabled_color1
+                self.current_color2 = self.disabled_color2
         return self
 
     def calc_align(self) -> None:
@@ -194,8 +203,9 @@ class NWinButton:
             )
 
     def _on_mouse_leave(self, event: pygame.event.Event, bind: bool) -> None:
-        self.current_color1 = self.color1
-        self.current_color2 = self.color2
+        if self.is_enabled:
+            self.current_color1 = self.color1
+            self.current_color2 = self.color2
         if bind:
             self.on_mouse_leave(event.pos)  # type: ignore
 
